@@ -42,6 +42,6 @@ private:
 	QPointF mNewItemOffset;
 };
 
-}
+} // namespace kImageAnnotator
 
 #endif //KIMAGEANNOTATOR_CROPCOMMAND_H
