@@ -29,6 +29,7 @@
 
 #include "CropView.h"
 #include "src/gui/selection/SelectionHandler.h"
+#include "src/gui/selection/SelectionHandlesAll.h"
 #include "src/annotations/core/AnnotationArea.h"
 #include "src/common/helper/KeyHelper.h"
 #include "src/common/provider/ScaledSizeProvider.h"
@@ -57,7 +58,7 @@ private:
 	CropView *mCropView;
 	QVBoxLayout *mMainLayout;
 	QHBoxLayout *mPanelLayout;
-	QPushButton *mCropButton;
+	QPushButton *mApplyButton;
 	QPushButton *mCancelButton;
 	QLineEdit *mPositionXLineEdit;
 	QLineEdit *mPositionYLineEdit;
