@@ -40,8 +40,8 @@ void AnnotationTabContextMenuTest::TestCustomActionTriggered_Should_CallInnerAct
 void AnnotationTabContextMenuTest::TestAddCustomActions_Should_SetTextIconAndToolTipInOuterAction() 
 {
     QAction customAction;
-    customAction.setText(QLatin1Literal("LaLa"));
-    customAction.setToolTip(QLatin1Literal("Hello Hello"));
+    customAction.setText(QStringLiteral("LaLa"));
+    customAction.setToolTip(QStringLiteral("Hello Hello"));
     customAction.setIcon(QIcon());
     QWidget parent;
     AnnotationTabContextMenu menu(&parent);
@@ -68,4 +68,4 @@ void AnnotationTabContextMenuTest::TestCustomActionChanged_Should_UpdateEnabledS
     QCOMPARE(customAction.isEnabled(), outerAction->isEnabled());
 }
 
-TEST_MAIN(AnnotationTabContextMenuTest);
\ No newline at end of file
+TEST_MAIN(AnnotationTabContextMenuTest);
