@@ -44,6 +44,13 @@
         <translation>删除</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::AnnotationControlsWidget</name>
+    <message>
+        <source>Controls</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::AnnotationGeneralSettings</name>
     <message>
@@ -82,12 +89,20 @@
     </message>
     <message>
         <source>Item Shadow</source>
-        <translation type="unfinished">项影</translation>
+        <translation>元素的阴影</translation>
     </message>
     <message>
         <source>Item Settings</source>
         <translation>元素设置</translation>
     </message>
+    <message>
+        <source>Scale</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Opacity</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::AnnotationTabContextMenu</name>
@@ -130,6 +145,37 @@
         <translation>关闭</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::Controls</name>
+    <message>
+        <source>Undo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Redo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Crop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation>旋转</translation>
+    </message>
+    <message>
+        <source>Modify canvas</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::CropWidget</name>
     <message>
@@ -157,6 +203,25 @@
         <translation>应用</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::CutWidget</name>
+    <message>
+        <source>Vertical</source>
+        <translation>垂直</translation>
+    </message>
+    <message>
+        <source>Horizontal</source>
+        <translation>水平</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>应用</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>取消</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::FillModePicker</name>
     <message>
@@ -226,12 +291,13 @@
     <name>kImageAnnotator::ModifyCanvasWidget</name>
     <message>
         <source>Restricted</source>
-        <translation type="unfinished"></translation>
+        <translation>受限</translation>
     </message>
     <message>
         <source>When enabled enforces the canvas
 to include the background image.</source>
-        <translation type="unfinished"></translation>
+        <translation>启用后强制画布
+ 包括背景图像。</translation>
     </message>
     <message>
         <source>X:</source>
@@ -286,7 +352,7 @@ to include the background image.</source>
     </message>
     <message>
         <source>Arbitrary</source>
-        <translation type="unfinished"></translation>
+        <translation>任意</translation>
     </message>
     <message>
         <source>Positive values rotate clockwise, negative values counter clockwise.
@@ -458,5 +524,17 @@ Rotating by non 90° multipliers might introduce loss of quality.</source>
         <source>Reset Zoom (%1)</source>
         <translation>重置大小（%1）</translation>
     </message>
+    <message>
+        <source>Reset Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fit Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fit image to view (%1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
